import React from 'react';
import { NativeEventEmitter, NativeModules, Platform } from 'react-native';
import BasePortalView from './BasePortalView';
const {
  IONPortalPubSub,
  IONPortalsReactNative,
  IONPortalsWebVitals
} = NativeModules;
export const PortalView = props => {
  let webVitals;
  if (props.webVitals) {
    webVitals = [];
    if (props.webVitals.firstContentfulPaint) {
      webVitals.push('fcp');
      registerVital(props.portal.name, 'fcp', props.webVitals.firstContentfulPaint);
    }
    if (props.webVitals.firstInputDelay) {
      webVitals.push('fid');
      registerVital(props.portal.name, 'fid', props.webVitals.firstInputDelay);
    }
    if (props.webVitals.timeToFirstByte) {
      webVitals.push('ttfb');
      registerVital(props.portal.name, 'ttfb', props.webVitals.timeToFirstByte);
    }
  }
  const newProps = {
    ...props,
    webVitals: undefined
  };
  // @ts-ignore
  newProps.portal.webVitals = webVitals;
  return /*#__PURE__*/React.createElement(BasePortalView, newProps);
};

/**
 * The data that is received from a subscription event.
 */

const PortalsPubSub = new NativeEventEmitter(IONPortalPubSub);

/**
 * Subscribes to messages for a topic
 *
 * @param topic The topic to subscribe to
 * @param onMessageReceived The callback to invoke when a message is received
 * @returns A Promise<number> containing the unique subscription reference. This will need to be stored for calling {@link unsubscribe}.
 */
export const subscribe = (topic, onMessageReceived) => {
  return PortalsPubSub.addListener(`PortalsSubscription:${topic}`, message => {
    onMessageReceived(message);
  });
};

/**
 * Publishes a message to the provided topic
 *
 * @param topic The topic to publish the message to
 * @param data The data to publish to subscribers
 */
export const publish = (topic, data) => {
  const msg = {
    message: data
  };
  IONPortalPubSub.publish(topic, msg);
};
const webVitalsMap = new Map();
const WebVitals = new NativeEventEmitter(IONPortalsWebVitals);
const registerVital = (portalName, vital, callback) => {
  if (Platform.OS === 'ios' && vital !== 'fcp') return;
  const listener = WebVitals.addListener(`vitals:${vital}`, event => {
    if (event.portalName === portalName) {
      callback(event.duration);
    }
  });
  webVitalsMap.set(`${portalName}-vitals:${vital}`, listener);
};
/**
 * Validates that a valid registration key has been procured from http://ionic.io/register-portals
 * @param key The registration key
 * @returns Promise<void>
 */
export const register = async key => {
  return IONPortalsReactNative.register(key);
};

/**
 * The configuration of a web application to be embedded in a React Native application.
 */

/**
 * Props needed for rendering a {@link Portal}
 */

/** Data needed to register a live update to be managed */

/** Used for communicating sync results of multiple live updates */

/**
 * Configures LiveUpdates to cyrptographically verify the contents of the downloaded bundles.
 * This method must be called before any LiveUpdates are registered otherwise they will no longer be tracked.
 *
 * @param pathToKey The *relative* path to the public key for verification.
 * This path should be the same relatibe to the main application bundle on iOS and the assets directory on Android.
 * @returns Promise<void>
 */
export const enableSecureLiveUpdates = async pathToKey => {
  return IONPortalsReactNative.enableSecureLiveUpdates(pathToKey);
};

/**
 * Syncs a single live update.
 *
 * @param appId The AppFlow application ID to sync.
 * @returns A Promise<LiveUpdate>. A failure should result in a {@link LiveUpdateError}.
 */
export const syncOne = async appId => {
  return IONPortalsReactNative.syncOne(appId);
};

/**
 * Syncs many live updates.
 *
 * @param appIds The AppFlow application IDs to sync.
 * @returns Promise<SyncResults>
 */
export const syncSome = async appIds => {
  return IONPortalsReactNative.syncSome(appIds);
};

/**
 * Syncs all registered LiveUpdates
 * @returns Promise<SyncResults>
 */
export const syncAll = async () => {
  return IONPortalsReactNative.syncAll();
};
//# sourceMappingURL=index.js.map